build_spatial_query

Function build_spatial_query 

pub fn build_spatial_query(
    scene: &StaticSpatialScene,
    actors: &[SpatialActor],
) -> Result<impl SpatialQuery + SpatialQueryDiagnostics + use<>, SpatialQueryError>
Build the selected spatial query without exposing its concrete implementation.

Errors

Returns SpatialQueryError when the scene or actor geometry is invalid.