pub fn build_spatial_query(
scene: &StaticSpatialScene,
actors: &[SpatialActor],
) -> Result<impl SpatialQuery + SpatialQueryDiagnostics + use<>, SpatialQueryError>Expand description
Build the selected spatial query without exposing its concrete implementation.
Errors
Returns SpatialQueryError when the scene or actor geometry is invalid.